==> eam-wshub-proxyclient-11.6-2-sources.jar: net/datastream/schemas/mp_entities/workorderschedule_001/WorkOrderSchedule.java <==

package net.datastream.schemas.mp_entities.workorderschedule_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.DEPARTMENTID_Type;
import net.datastream.schemas.mp_fields.EQUIPMENTID_Type;
import net.datastream.schemas.mp_fields.PERSONID_Type;
import net.datastream.schemas.mp_fields.SHIFTID_Type;
import net.datastream.schemas.mp_fields.TRADEID_Type;
import net.datastream.schemas.mp_fields.WOSCHEDULEID;
import org.openapplications.oagis_segments.AMOUNT;
import org.openapplications.oagis_segments.DATETIME;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}WOSCHEDULEID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SCHEDULEDDATE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SCHEDULEDHOURS" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}STARTTIME" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ENDTIME" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TRADEID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DEPARTMENTID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SHIFTID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EMPLOYEE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}MAINTENANCEEQUIPMENTID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ENTEREDBY" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}FROZEN" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}WOSCHEDULECOMMENT" minOccurs="0"/>
 *       &lt;/sequence>
 *       &lt;attribute name="recordid" type="{http://www.w3.org/2001/XMLSchema}long" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "woscheduleid",
    "scheduleddate",
    "scheduledhours",
    "starttime",
    "endtime",
    "tradeid",
    "departmentid",
    "shiftid",
    "employee",
    "maintenanceequipmentid",
    "enteredby",
    "frozen",
    "woschedulecomment"
})
@XmlRootElement(name = "WorkOrderSchedule")
public class WorkOrderSchedule {

    @XmlElement(name = "WOSCHEDULEID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected WOSCHEDULEID woscheduleid;
    @XmlElement(name = "SCHEDULEDDATE", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected DATETIME scheduleddate;
    @XmlElement(name = "SCHEDULEDHOURS", namespace = "http://schemas.datastream.net/MP_fields")
    protected Double scheduledhours;
    @XmlElement(name = "STARTTIME", namespace = "http://schemas.datastream.net/MP_fields")
    protected AMOUNT starttime;
    @XmlElement(name = "ENDTIME", namespace = "http://schemas.datastream.net/MP_fields")
    protected AMOUNT endtime;
    @XmlElement(name = "TRADEID", namespace = "http://schemas.datastream.net/MP_fields")
    protected TRADEID_Type tradeid;
    @XmlElement(name = "DEPARTMENTID", namespace = "http://schemas.datastream.net/MP_fields")
    protected DEPARTMENTID_Type departmentid;
    @XmlElement(name = "SHIFTID", namespace = "http://schemas.datastream.net/MP_fields")
    protected SHIFTID_Type shiftid;
    @XmlElement(name = "EMPLOYEE", namespace = "http://schemas.datastream.net/MP_fields")
    protected PERSONID_Type employee;
    @XmlElement(name = "MAINTENANCEEQUIPMENTID", namespace = "http://schemas.datastream.net/MP_fields")
    protected EQUIPMENTID_Type maintenanceequipmentid;
    @XmlElement(name = "ENTEREDBY", namespace = "http://schemas.datastream.net/MP_fields")
    protected String enteredby;
    @XmlElement(name = "FROZEN", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "-")
    protected String frozen;
    @XmlElement(name = "WOSCHEDULECOMMENT", namespace = "http://schemas.datastream.net/MP_fields")
    protected String woschedulecomment;
    @XmlAttribute(name = "recordid")
    protected Long recordid;

    /**
     * Obtient la valeur de la propriété woscheduleid.
     * 
     * @return
     *     possible object is
     *     {@link WOSCHEDULEID }
     *     
     */
    public WOSCHEDULEID getWOSCHEDULEID() {
        return woscheduleid;
    }

    /**
     * Définit la valeur de la propriété woscheduleid.
     * 
     * @param value
     *     allowed object is
     *     {@link WOSCHEDULEID }
     *     
     */
    public void setWOSCHEDULEID(WOSCHEDULEID value) {
        this.woscheduleid = value;
    }

    /**
     * Obtient la valeur de la propriété scheduleddate.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getSCHEDULEDDATE() {
        return scheduleddate;
    }

    /**
     * Définit la valeur de la propriété scheduleddate.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setSCHEDULEDDATE(DATETIME value) {
        this.scheduleddate = value;
    }

    /**
     * Obtient la valeur de la propriété scheduledhours.
     * 
     * @return
     *     possible object is
     *     {@link Double }
     *     
     */
    public Double getSCHEDULEDHOURS() {
        return scheduledhours;
    }

    /**
     * Définit la valeur de la propriété scheduledhours.
     * 
     * @param value
     *     allowed object is
     *     {@link Double }
     *     
     */
    public void setSCHEDULEDHOURS(Double value) {
        this.scheduledhours = value;
    }

    /**
     * Obtient la valeur de la propriété starttime.
     * 
     * @return
     *     possible object is
     *     {@link AMOUNT }
     *     
     */
    public AMOUNT getSTARTTIME() {
        return starttime;
    }

    /**
     * Définit la valeur de la propriété starttime.
     * 
     * @param value
     *     allowed object is
     *     {@link AMOUNT }
     *     
     */
    public void setSTARTTIME(AMOUNT value) {
        this.starttime = value;
    }

    /**
     * Obtient la valeur de la propriété endtime.
     * 
     * @return
     *     possible object is
     *     {@link AMOUNT }
     *     
     */
    public AMOUNT getENDTIME() {
        return endtime;
    }

    /**
     * Définit la valeur de la propriété endtime.
     * 
     * @param value
     *     allowed object is
     *     {@link AMOUNT }
     *     
     */
    public void setENDTIME(AMOUNT value) {
        this.endtime = value;
    }

    /**
     * Obtient la valeur de la propriété tradeid.
     * 
     * @return
     *     possible object is
     *     {@link TRADEID_Type }
     *     
     */
    public TRADEID_Type getTRADEID() {
        return tradeid;
    }

    /**
     * Définit la valeur de la propriété tradeid.
     * 
     * @param value
     *     allowed object is
     *     {@link TRADEID_Type }
     *     
     */
    public void setTRADEID(TRADEID_Type value) {
        this.tradeid = value;
    }

    /**
     * Obtient la valeur de la propriété departmentid.
     * 
     * @return
     *     possible object is
     *     {@link DEPARTMENTID_Type }
     *     
     */
    public DEPARTMENTID_Type getDEPARTMENTID() {
        return departmentid;
    }

    /**
     * Définit la valeur de la propriété departmentid.
     * 
     * @param value
     *     allowed object is
     *     {@link DEPARTMENTID_Type }
     *     
     */
    public void setDEPARTMENTID(DEPARTMENTID_Type value) {
        this.departmentid = value;
    }

    /**
     * Obtient la valeur de la propriété shiftid.
     * 
     * @return
     *     possible object is
     *     {@link SHIFTID_Type }
     *     
     */
    public SHIFTID_Type getSHIFTID() {
        return shiftid;
    }

    /**
     * Définit la valeur de la propriété shiftid.
     * 
     * @param value
     *     allowed object is
     *     {@link SHIFTID_Type }
     *     
     */
    public void setSHIFTID(SHIFTID_Type value) {
        this.shiftid = value;
    }

    /**
     * Obtient la valeur de la propriété employee.
     * 
     * @return
     *     possible object is
     *     {@link PERSONID_Type }
     *     
     */
    public PERSONID_Type getEMPLOYEE() {
        return employee;
    }

    /**
     * Définit la valeur de la propriété employee.
     * 
     * @param value
     *     allowed object is
     *     {@link PERSONID_Type }
     *     
     */
    public void setEMPLOYEE(PERSONID_Type value) {
        this.employee = value;
    }

    /**
     * Obtient la valeur de la propriété maintenanceequipmentid.
     * 
     * @return
     *     possible object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public EQUIPMENTID_Type getMAINTENANCEEQUIPMENTID() {
        return maintenanceequipmentid;
    }

    /**
     * Définit la valeur de la propriété maintenanceequipmentid.
     * 
     * @param value
     *     allowed object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public void setMAINTENANCEEQUIPMENTID(EQUIPMENTID_Type value) {
        this.maintenanceequipmentid = value;
    }

    /**
     * Obtient la valeur de la propriété enteredby.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getENTEREDBY() {
        return enteredby;
    }

    /**
     * Définit la valeur de la propriété enteredby.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setENTEREDBY(String value) {
        this.enteredby = value;
    }

    /**
     * Obtient la valeur de la propriété frozen.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getFROZEN() {
        return frozen;
    }

    /**
     * Définit la valeur de la propriété frozen.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setFROZEN(String value) {
        this.frozen = value;
    }

    /**
     * Obtient la valeur de la propriété woschedulecomment.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getWOSCHEDULECOMMENT() {
        return woschedulecomment;
    }

    /**
     * Définit la valeur de la propriété woschedulecomment.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setWOSCHEDULECOMMENT(String value) {
        this.woschedulecomment = value;
    }

    /**
     * Obtient la valeur de la propriété recordid.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getRecordid() {
        return recordid;
    }

    /**
     * Définit la valeur de la propriété recordid.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setRecordid(Long value) {
        this.recordid = value;
    }

}

==> eam-wshub-proxyclient-11.7-0-sources.jar: net/datastream/schemas/mp_entities/workorderschedule_001/WorkOrderSchedule.java <==

package net.datastream.schemas.mp_entities.workorderschedule_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.DEPARTMENTID_Type;
import net.datastream.schemas.mp_fields.EQUIPMENTID_Type;
import net.datastream.schemas.mp_fields.PERSONID_Type;
import net.datastream.schemas.mp_fields.SHIFTID_Type;
import net.datastream.schemas.mp_fields.TRADEID_Type;
import net.datastream.schemas.mp_fields.WOSCHEDULEID;
import org.openapplications.oagis_segments.AMOUNT;
import org.openapplications.oagis_segments.DATETIME;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}WOSCHEDULEID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SCHEDULEDDATE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SCHEDULEDHOURS" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}STARTTIME" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ENDTIME" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TRADEID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DEPARTMENTID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SHIFTID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EMPLOYEE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}MAINTENANCEEQUIPMENTID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ENTEREDBY" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}FROZEN" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}WOSCHEDULECOMMENT" minOccurs="0"/>
 *       &lt;/sequence>
 *       &lt;attribute name="recordid" type="{http://www.w3.org/2001/XMLSchema}long" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "woscheduleid",
    "scheduleddate",
    "scheduledhours",
    "starttime",
    "endtime",
    "tradeid",
    "departmentid",
    "shiftid",
    "employee",
    "maintenanceequipmentid",
    "enteredby",
    "frozen",
    "woschedulecomment"
})
@XmlRootElement(name = "WorkOrderSchedule")
public class WorkOrderSchedule {

    @XmlElement(name = "WOSCHEDULEID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected WOSCHEDULEID woscheduleid;
    @XmlElement(name = "SCHEDULEDDATE", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected DATETIME scheduleddate;
    @XmlElement(name = "SCHEDULEDHOURS", namespace = "http://schemas.datastream.net/MP_fields")
    protected Double scheduledhours;
    @XmlElement(name = "STARTTIME", namespace = "http://schemas.datastream.net/MP_fields")
    protected AMOUNT starttime;
    @XmlElement(name = "ENDTIME", namespace = "http://schemas.datastream.net/MP_fields")
    protected AMOUNT endtime;
    @XmlElement(name = "TRADEID", namespace = "http://schemas.datastream.net/MP_fields")
    protected TRADEID_Type tradeid;
    @XmlElement(name = "DEPARTMENTID", namespace = "http://schemas.datastream.net/MP_fields")
    protected DEPARTMENTID_Type departmentid;
    @XmlElement(name = "SHIFTID", namespace = "http://schemas.datastream.net/MP_fields")
    protected SHIFTID_Type shiftid;
    @XmlElement(name = "EMPLOYEE", namespace = "http://schemas.datastream.net/MP_fields")
    protected PERSONID_Type employee;
    @XmlElement(name = "MAINTENANCEEQUIPMENTID", namespace = "http://schemas.datastream.net/MP_fields")
    protected EQUIPMENTID_Type maintenanceequipmentid;
    @XmlElement(name = "ENTEREDBY", namespace = "http://schemas.datastream.net/MP_fields")
    protected String enteredby;
    @XmlElement(name = "FROZEN", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "-")
    protected String frozen;
    @XmlElement(name = "WOSCHEDULECOMMENT", namespace = "http://schemas.datastream.net/MP_fields")
    protected String woschedulecomment;
    @XmlAttribute(name = "recordid")
    protected Long recordid;

    /**
     * Gets the value of the woscheduleid property.
     * 
     * @return
     *     possible object is
     *     {@link WOSCHEDULEID }
     *     
     */
    public WOSCHEDULEID getWOSCHEDULEID() {
        return woscheduleid;
    }

    /**
     * Sets the value of the woscheduleid property.
     * 
     * @param value
     *     allowed object is
     *     {@link WOSCHEDULEID }
     *     
     */
    public void setWOSCHEDULEID(WOSCHEDULEID value) {
        this.woscheduleid = value;
    }

    /**
     * Gets the value of the scheduleddate property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getSCHEDULEDDATE() {
        return scheduleddate;
    }

    /**
     * Sets the value of the scheduleddate property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setSCHEDULEDDATE(DATETIME value) {
        this.scheduleddate = value;
    }

    /**
     * Gets the value of the scheduledhours property.
     * 
     * @return
     *     possible object is
     *     {@link Double }
     *     
     */
    public Double getSCHEDULEDHOURS() {
        return scheduledhours;
    }

    /**
     * Sets the value of the scheduledhours property.
     * 
     * @param value
     *     allowed object is
     *     {@link Double }
     *     
     */
    public void setSCHEDULEDHOURS(Double value) {
        this.scheduledhours = value;
    }

    /**
     * Gets the value of the starttime property.
     * 
     * @return
     *     possible object is
     *     {@link AMOUNT }
     *     
     */
    public AMOUNT getSTARTTIME() {
        return starttime;
    }

    /**
     * Sets the value of the starttime property.
     * 
     * @param value
     *     allowed object is
     *     {@link AMOUNT }
     *     
     */
    public void setSTARTTIME(AMOUNT value) {
        this.starttime = value;
    }

    /**
     * Gets the value of the endtime property.
     * 
     * @return
     *     possible object is
     *     {@link AMOUNT }
     *     
     */
    public AMOUNT getENDTIME() {
        return endtime;
    }

    /**
     * Sets the value of the endtime property.
     * 
     * @param value
     *     allowed object is
     *     {@link AMOUNT }
     *     
     */
    public void setENDTIME(AMOUNT value) {
        this.endtime = value;
    }

    /**
     * Gets the value of the tradeid property.
     * 
     * @return
     *     possible object is
     *     {@link TRADEID_Type }
     *     
     */
    public TRADEID_Type getTRADEID() {
        return tradeid;
    }

    /**
     * Sets the value of the tradeid property.
     * 
     * @param value
     *     allowed object is
     *     {@link TRADEID_Type }
     *     
     */
    public void setTRADEID(TRADEID_Type value) {
        this.tradeid = value;
    }

    /**
     * Gets the value of the departmentid property.
     * 
     * @return
     *     possible object is
     *     {@link DEPARTMENTID_Type }
     *     
     */
    public DEPARTMENTID_Type getDEPARTMENTID() {
        return departmentid;
    }

    /**
     * Sets the value of the departmentid property.
     * 
     * @param value
     *     allowed object is
     *     {@link DEPARTMENTID_Type }
     *     
     */
    public void setDEPARTMENTID(DEPARTMENTID_Type value) {
        this.departmentid = value;
    }

    /**
     * Gets the value of the shiftid property.
     * 
     * @return
     *     possible object is
     *     {@link SHIFTID_Type }
     *     
     */
    public SHIFTID_Type getSHIFTID() {
        return shiftid;
    }

    /**
     * Sets the value of the shiftid property.
     * 
     * @param value
     *     allowed object is
     *     {@link SHIFTID_Type }
     *     
     */
    public void setSHIFTID(SHIFTID_Type value) {
        this.shiftid = value;
    }

    /**
     * Gets the value of the employee property.
     * 
     * @return
     *     possible object is
     *     {@link PERSONID_Type }
     *     
     */
    public PERSONID_Type getEMPLOYEE() {
        return employee;
    }

    /**
     * Sets the value of the employee property.
     * 
     * @param value
     *     allowed object is
     *     {@link PERSONID_Type }
     *     
     */
    public void setEMPLOYEE(PERSONID_Type value) {
        this.employee = value;
    }

    /**
     * Gets the value of the maintenanceequipmentid property.
     * 
     * @return
     *     possible object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public EQUIPMENTID_Type getMAINTENANCEEQUIPMENTID() {
        return maintenanceequipmentid;
    }

    /**
     * Sets the value of the maintenanceequipmentid property.
     * 
     * @param value
     *     allowed object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public void setMAINTENANCEEQUIPMENTID(EQUIPMENTID_Type value) {
        this.maintenanceequipmentid = value;
    }

    /**
     * Gets the value of the enteredby property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getENTEREDBY() {
        return enteredby;
    }

    /**
     * Sets the value of the enteredby property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setENTEREDBY(String value) {
        this.enteredby = value;
    }

    /**
     * Gets the value of the frozen property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getFROZEN() {
        return frozen;
    }

    /**
     * Sets the value of the frozen property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setFROZEN(String value) {
        this.frozen = value;
    }

    /**
     * Gets the value of the woschedulecomment property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getWOSCHEDULECOMMENT() {
        return woschedulecomment;
    }

    /**
     * Sets the value of the woschedulecomment property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setWOSCHEDULECOMMENT(String value) {
        this.woschedulecomment = value;
    }

    /**
     * Gets the value of the recordid property.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getRecordid() {
        return recordid;
    }

    /**
     * Sets the value of the recordid property.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setRecordid(Long value) {
        this.recordid = value;
    }

}
